@@ -4,6 +4,11 @@
 // @require       utils.js
 // ==/UserScript==
 
+// This placeholder gets munged with real data at build time.
+var WebappsGettextDict = JSON.parse(unescape(
+    "%7B%22GETTEXT%22%3A%22PLACEHOLDER%22%7D"
+));
+
 window.Unity = external.getUnityObject(1);
 
 function isCorrectPage() {
@@ -20,22 +25,21 @@ function isCorrectPage() {
 
 function messagingIndicatorSetup() {
     var countElement = document.getElementById('g_mail_events');
-    function checkMessangesCount() {
+    function checkMessagesCount() {
         var count = countElement.textContent;
 
         Unity.MessagingIndicator.showIndicator(_("Inbox"), { count: count });
     }
 
-    countElement.addEventListener('DOMSubtreeModified', wrapCallback(checkMessangesCount), false);
+    countElement.addEventListener('DOMSubtreeModified', wrapCallback(checkMessagesCount), false);
 
-    checkMessangesCount();
+    checkMessagesCount();
 }
 
 if (isCorrectPage()) {
     Unity.init({ name: _("mail.ru"),
-		 domain: 'mail.ru',
-		 homepage: 'http://mail.ru/',
+                 domain: 'mail.ru',
+                 homepage: 'http://mail.ru/',
                  iconUrl: "icon://unity-webapps-mail-ru",
                  onInit: wrapCallback(messagingIndicatorSetup) });
 }
-
